@@ -35,7 +35,7 @@ your system.
 
 use XSLoader;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 XSLoader::load( __PACKAGE__, $VERSION );
 
@@ -270,6 +270,19 @@ QuickJS supports Linux & macOS natively, so these work without issue.
 FreeBSD, OpenBSD, & Cygwin work after a few patches that we apply when
 building this library. (Hopefully these will eventually merge into QuickJS.)
 
+=head1 LIBATOMIC
+
+QuickJS uses C11 atomics. Most platforms implement that functionality in
+hardware, but others (e.g., arm32) don’t. To fill that void, we need to link
+to libatomic.
+
+This library’s build logic detects whether libatomic is necessary and will
+only link to it if needed. If, for some reason, you need manual control over
+that linking, set C<JS_QUICKJS_LINK_LIBATOMIC> in the environment to 1 or a
+falsy value.
+
+If you don’t know what any of that means, you can probably ignore it.
+
 =head1 SEE ALSO
 
 Other JavaScript modules on CPAN include:
